@@ -11,4 +11,4 @@ def default(args, config, logger=None):
 
     sync(args, config, logger=logger)
     command = "cd {0} && source /etc/profile && `which chef-solo` -c {0}/{1} -j {0}/dna/{2} -l {3}"
-    sudo_dry(command.format(args.chef_file_dest, args.config_path, "default.json", args.loglevel), args, logger=logger)
+    return sudo_dry(command.format(args.chef_file_dest, args.config_path, "default.json", args.loglevel), args, logger=logger)
