@@ -1,11 +1,12 @@
 from __future__ import with_statement
 
 import argparse
-import collections
+import errno
 import logging
 import multiprocessing
-import random
+import os
 import Queue
+import random
 import signal
 import sys
 import time
@@ -82,12 +83,14 @@ def run_in_parallel(args, hosts, logger=None):
                    _red=31, _green=32, _yellow=33,
                    _blue=34, _magenta=35, _cyan=36)
 
+    run_time = int(time.time())
+
     workers = []
     pool_size = 12  # we don't have more colors than this :P
     for worker_id in range(pool_size):
         color = _colors.pop(random.choice(_colors.keys()), None)
         tmp = multiprocessing.Process(target=_worker,
-                                      args=(worker_id, task_queue, result_queue, commands, color, args, logger))
+                                      args=(worker_id, task_queue, result_queue, commands, color, run_time, args, logger))
         tmp.start()
         workers.append(tmp)
 
@@ -108,13 +111,13 @@ def run_in_parallel(args, hosts, logger=None):
         # pass  # return of each command can be accessed via result_queue.get(block=False)
 
 
-def _worker(worker_id, task_queue, result_queue, commands, color, args, logger):
+def _worker(worker_id, task_queue, result_queue, commands, color, run_time, args, logger):
     signal.signal(signal.SIGINT, signal.SIG_IGN)
-    logger = _update_handlers(logger, color, args)
 
     while not task_queue.empty():
         try:
             task = task_queue.get(block=False)
+            logger = _update_handlers(logger, color, task['host'], run_time, args)
             logger.info("Running {0} against {1}".format(
                 args.command,
                 task['host']
@@ -134,25 +137,45 @@ def _worker(worker_id, task_queue, result_queue, commands, color, args, logger):
         except Queue.Empty:
             pass
 
-def _update_handlers(logger, color, args):
+
+def _update_handlers(logger, color, host, run_time, args):
     has_args = args is not None and type(args) == argparse.Namespace
-    is_debug = has_args and args.debug == True
 
     logger.handlers = []
-    formatter = logging.Formatter('\x1b[{0};1m[{1}]\x1b[0m [%(asctime)s] %(levelname)-7s %(message)s'.format(color, multiprocessing.current_process().name))
+    output = None
+    if has_args:
+        if args.output is not None:
+            output = args.output
+        elif args.log_path is not None:
+            output = os.path.join(os.path.realpath(args.log_path), str(run_time), host + '.log')
+            _make_sure_path_exists(os.path.realpath(args.log_path))
+            _make_sure_path_exists(os.path.join(os.path.realpath(args.log_path), str(run_time)))
 
-    handler = logging.StreamHandler()
-    if has_args and args.output is not None:
-        handler = logging.FileHandler(output)
 
-    handler.setFormatter(formatter)
-    logger.addHandler(handler)
+    if output is not None:
+        fileFormatter = logging.Formatter('[%(asctime)s] %(levelname)-7s %(message)s')
+        fileHandler = logging.FileHandler(output)
+        fileHandler.setFormatter(fileFormatter)
+        logger.addHandler(fileHandler)
+
+    streamFormatter = logging.Formatter('\x1b[{0};1m[{1}]\x1b[0m [%(asctime)s] %(levelname)-7s %(message)s'.format(color, host))
+    streamHandler = logging.StreamHandler()
+    streamHandler.setFormatter(streamFormatter)
+    logger.addHandler(streamHandler)
 
     sys.stdout = StreamToLogger(logger, logging.INFO)
     sys.stderr = StreamToLogger(logger, logging.ERROR)
     return logger
 
 
+def _make_sure_path_exists(path):
+    try:
+        os.makedirs(path)
+    except OSError as exception:
+        if exception.errno != errno.EEXIST:
+            raise
+
+
 def _run_command(host, config, commands, args, logger):
     env.use_ssh_config = True
     env.user = args.user
