@@ -8,4 +8,4 @@ def test(args, config, logger=None):
     if logger is None:
         logger = setup_custom_logger('chef-solo-cup', args)
 
-    sudo_dry("hostname", args, logger=logger)
+    return sudo_dry("hostname", args, logger=logger)
